==> haskell-tasty-expected-failure-0.11.1.1-37-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-expected-failure
version: 0.11.1.1
id: tasty-expected-failure-0.11.1.1-AfDGYzeuf1T7kgBvym2Bux
key: tasty-expected-failure-0.11.1.1-AfDGYzeuf1T7kgBvym2Bux
license: MIT
copyright: 2015 Joachim Breitner
maintainer: mail@joachim-breitner.de
author: Joachim Breitner
homepage: http://github.com/nomeata/tasty-expected-failure
synopsis: Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.
    .
    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.
    .
    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.
    .
    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.
category: Testing
abi: ee173ccb876159e74d410f475d364838
exposed: True
exposed-modules:
    Test.Tasty.ExpectedFailure
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-expected-failure-0.11.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-expected-failure-0.11.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-expected-failure-0.11.1.1
hs-libraries: HStasty-expected-failure-0.11.1.1-AfDGYzeuf1T7kgBvym2Bux
depends:
    base-4.12.0.0 tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2.3-5ITMgF4T2W2IIIlDwr7h1z
haddock-interfaces: /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock
haddock-html: /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-expected-failure-0.11.1.1-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-expected-failure
version: 0.11.1.1
id: tasty-expected-failure-0.11.1.1-HJi3v8Dgnzd3tMsZ6YuVe8
key: tasty-expected-failure-0.11.1.1-HJi3v8Dgnzd3tMsZ6YuVe8
license: MIT
copyright: 2015 Joachim Breitner
maintainer: mail@joachim-breitner.de
author: Joachim Breitner
homepage: http://github.com/nomeata/tasty-expected-failure
synopsis: Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.
    .
    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.
    .
    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.
    .
    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.
category: Testing
abi: da62e7721ac5e31bbcd77380f76fb1d3
exposed: True
exposed-modules:
    Test.Tasty.ExpectedFailure
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-expected-failure-0.11.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-expected-failure-0.11.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-expected-failure-0.11.1.1
hs-libraries: HStasty-expected-failure-0.11.1.1-HJi3v8Dgnzd3tMsZ6YuVe8
depends:
    base-4.12.0.0 tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2.3-9rbI7SmrRn85ofgbCsxp2n
haddock-interfaces: /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock
haddock-html: /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
